CoinDataPoint class

Constructors

CoinDataPoint.fromArray(List dataPoint)

Properties

date ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isNull → bool
no setter
price ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override