FullCoin class

Inheritance

Constructors

FullCoin.fromJson(Map<String, dynamic> json)

Properties

ath → double?
final
athChangePercentage → double?
final
athDate ↔ DateTime?
getter/setter pair
atl → double?
final
atlChangePercentage → double?
final
atlDate ↔ DateTime?
getter/setter pair
circulatingSupply → double?
final
currentPrice → double?
final
fullyDilutedValuation → double?
final
hashCode → int
The hash code for this object.
no setterinherited
high24h → double?
final
id ↔ String
getter/setter pairinherited
image → String?
final
isNull → bool
no setterinherited
json ↔ Map<String, dynamic>
finalgetter/setter pairinherited-setteroverride-getter
lastUpdated ↔ DateTime?
getter/setter pair
low24h → double?
final
marketCap → double?
final
marketCapChange24h → double?
final
marketCapChangePercentage24h → double?
final
marketCapRank → int?
final
maxSupply → double?
final
name ↔ String
getter/setter pairinherited
priceChange24h → double?
final
priceChangePercentage14dInCurrency → double?
final
priceChangePercentage1hInCurrency → double?
final
priceChangePercentage1yInCurrency → double?
final
priceChangePercentage200dInCurrency → double?
final
priceChangePercentage24h → double?
final
priceChangePercentage24hInCurrency → double?
final
priceChangePercentage30dInCurrency → double?
final
priceChangePercentage7dInCurrency → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkline7d ↔ List<double>
getter/setter pair
symbol ↔ String
getter/setter pairinherited
totalSupply → double?
final
totalVolume → double?
final

Methods

isError() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited