PricedCoinBase class

Implementers

Constructors

PricedCoinBase()
defaults to epoch
PricedCoinBase.fromJson(Map<String, dynamic> json)

Properties

data ↔ Map<String, double>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedAtTimeStamp ↔ DateTime
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dataAvailableIn() → List<String>
get24hChangeIn(String vsCurrency) → double
get24hVolIn(String vsCurrency) → double
getMarketCapIn(String vsCurrency) → double
getPriceIn(String vsCurrency) → double
used to obtain price of an instance of this crypto-token object in a currency of choice whose data is available in this instance
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited