SimpleToken class

Inheritance

Constructors

SimpleToken.fromJson(String contractAddress, Map<String, dynamic> json)

Properties

contractAddress ↔ String
getter/setter pair
data ↔ Map<String, double>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedAtTimeStamp ↔ DateTime
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(SimpleToken token) → SimpleToken
used to add two instances of the same token with different sets of currency:price data.
dataAvailableIn() → List<String>
inherited
get24hChangeIn(String vsCurrency) → double
inherited
get24hVolIn(String vsCurrency) → double
inherited
getMarketCapIn(String vsCurrency) → double
inherited
getPriceIn(String vsCurrency) → double
used to obtain price of an instance of this crypto-token object in a currency of choice whose data is available in this instance
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited