ContractToken class

Constructors

ContractToken()
ContractToken.fromJson(Map<String, dynamic> json)

Properties

assetPlatformId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isNull → bool
no setter
json ↔ Map<String, dynamic>
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited