Exchange class

Constructors

Exchange({String? id, String? name, int? yearEstablished, String? country, dynamic description, String? url, String? image, bool? hasTradingIncentive, int? trustScore, int? trustScoreRank, double? tradeVolume24hBtc, double? tradeVolume24hBtcNormalized, required dynamic json})
Exchange.fromJson(Map<String, dynamic> json)
factory

Properties

country ↔ String?
getter/setter pair
description ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
hasTradingIncentive ↔ bool?
getter/setter pair
id ↔ String?
getter/setter pair
image ↔ String?
getter/setter pair
json ↔ Map<String, dynamic>
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tradeVolume24hBtc ↔ double?
getter/setter pair
tradeVolume24hBtcNormalized ↔ double?
getter/setter pair
trustScore ↔ int?
getter/setter pair
trustScoreRank ↔ int?
getter/setter pair
url ↔ String?
getter/setter pair
yearEstablished ↔ int?
getter/setter pair

Methods

copyWith({String? id, String? name, int? yearEstablished, String? country, dynamic description, String? url, String? image, bool? hasTradingIncentive, int? trustScore, int? trustScoreRank, double? tradeVolume24hBtc, double? tradeVolume24hBtcNormalized, Map<String, dynamic> json = const {}}) → Exchange
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override