Item class

Constructors

Item({String? id, String? name, String? symbol, int? marketCapRank, String? thumb, String? large, int? score})
Item.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
getter/setter pair
large ↔ String?
getter/setter pair
marketCapRank ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ int?
getter/setter pair
symbol ↔ String?
getter/setter pair
thumb ↔ String?
getter/setter pair

Methods

copyWith({String? id, String? name, String? symbol, int? marketCapRank, String? thumb, String? large, int? score}) → Item
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override